@@ -447,11 +447,10 @@ class InfEngineServer:
                 if limit - counter <= 0:
                     break
 
-                if obj != ignore:
-                    if obj.is_dir():
-                        self._logger.debug(obj)
+                if obj != ignore and obj.is_dir():
+                    self._logger.debug(obj)
 
-                        counter += 1
+                    counter += 1
 
         return counter
 
@@ -504,7 +503,6 @@ class InfEngineServer:
 
         engine.install(dldata, dlsources, db_name=db_name)
 
-        engine.clean()
         self.clean()
         self.restart()
 
