@@ -229,39 +229,24 @@ class InfEngineServerEngine:
                 shutil.copy(sources_aliases, dldata_path / INF_ENGINE_FILE_ALIASES)
 
         # Switch softlinks
-        symlink_from = (
-            self._engine_dir
-            / INF_ENGINE_PATH_DLDATA
-            / dldata_path
-            / INF_ENGINE_FILE_DLDATA_VAR
-        )
         self._logger.debug(
-            f"Creating a symlink from {symlink_from}"
+            f"Creating a symlink from {dldata_path / INF_ENGINE_FILE_DLDATA_VAR}"
             f" to {self._engine_dir / INF_ENGINE_LINK_DLDATA}"
         )
         symlink(
-            symlink_from,
+            dldata_path / INF_ENGINE_FILE_DLDATA_VAR,
             self._engine_dir / (INF_ENGINE_PATH_DLDATA + INF_ENGINE_FILE_DLDATA_VAR),
             force=True,
         )
 
         if db_name == "dldata":
             if Path(dldata_path / INF_ENGINE_PATH_DLSOURCES).is_file():
-                symlink_from = (
-                    self._engine_dir
-                    / INF_ENGINE_PATH_DLDATA
-                    / dldata_path
-                    / INF_ENGINE_PATH_DLSOURCES
-                )
                 self._logger.debug(
-                    f"Creating a symlink from {symlink_from}"
+                    f"Creating a symlink from {dldata_path / INF_ENGINE_PATH_DLSOURCES}"
                     f" to {self._engine_dir / INF_ENGINE_LINK_DLSOURCES}"
                 )
                 symlink(
-                    self._engine_dir
-                    / INF_ENGINE_PATH_DLDATA
-                    / dldata_path
-                    / INF_ENGINE_PATH_DLSOURCES,
+                    dldata_path / INF_ENGINE_PATH_DLSOURCES,
                     self._engine_dir / INF_ENGINE_LINK_DLSOURCES,
                     force=True,
                 )
@@ -273,18 +258,12 @@ class InfEngineServerEngine:
                     Path(self._engine_dir / INF_ENGINE_LINK_DLSOURCES).unlink()
 
             if Path(dldata_path / INF_ENGINE_FILE_ALIASES).is_file():
-                symlink_from = (
-                    self._engine_dir
-                    / INF_ENGINE_PATH_DLDATA
-                    / dldata_path
-                    / INF_ENGINE_FILE_ALIASES
-                )
                 self._logger.debug(
-                    f"Creating a symlink from {symlink_from}"
+                    f"Creating a symlink from {dldata_path / INF_ENGINE_FILE_ALIASES}"
                     f" to {self._engine_dir / INF_ENGINE_LINK_ALIASES}"
                 )
                 symlink(
-                    symlink_from,
+                    dldata_path / INF_ENGINE_FILE_ALIASES,
                     self._engine_dir / INF_ENGINE_LINK_ALIASES,
                     force=True,
                 )
@@ -295,6 +274,8 @@ class InfEngineServerEngine:
                 if Path(self._engine_dir / INF_ENGINE_LINK_DLSOURCES).is_file():
                     Path(self._engine_dir / INF_ENGINE_LINK_DLSOURCES).unlink()
 
+        self.clean(ignore=dldata_path)
+
     def version(self):
         """ Get InfServer version. """
 
@@ -323,17 +304,19 @@ class InfEngineServerEngine:
 
         return None
 
-    def clean(self, dl_limit: int = 1):
+    def clean(self, ignore: Path, dl_limit: int = 1):
         """ Delete useless data. """
 
         self._logger.info(f"Cleaning InfServer Engine...")
 
-        count = self._clean_multidb(self._engine_dir / INF_ENGINE_PATH_DLDATA, dl_limit)
+        count = self._clean_multidb(
+            self._engine_dir / INF_ENGINE_PATH_DLDATA, ignore, dl_limit
+        )
 
         if count:
             self._logger.info(f"Deleted {count} DLData.")
 
-    def _clean_multidb(self, directory: Path, limit: int = 0) -> int:
+    def _clean_multidb(self, directory: Path, ignore: Path, limit: int = 0) -> int:
         """ Delete several DLData directories from the passed directory. """
 
         counter = 0
@@ -343,8 +326,9 @@ class InfEngineServerEngine:
                 if limit - counter <= 0:
                     break
 
-                if obj.is_dir():
-                    self._logger.info(obj)
+                if obj != ignore and obj.is_dir():
+                    self._logger.debug(f"Deleting directory: {obj}")
+                    shutil.rmtree(obj)
 
                     counter += 1
 
