@@ -6,15 +6,8 @@ import tempfile
 from pathlib import Path
 
 
-def create_temp_dir(parent_dir: Path) -> Path:  # tempfile.TemporaryDirectory:
-    """ Create a temp directory, which will be deleted on object destruction. """
-
-    current_time = datetime.datetime.now()
-
-    # temp_dir = tempfile.TemporaryDirectory(
-    #     prefix=f"{current_time.year}-{current_time.month}-{current_time.day}_{current_time.hour}-{current_time.minute}_",
-    #     dir=parent_dir,
-    # )
+def create_dir(parent_dir: Path) -> Path:
+    """ Create a directory. """
 
     randomized_name = "".join(random.choices(string.ascii_letters, k=6))
     temp_dir = (
@@ -26,6 +19,17 @@ def create_temp_dir(parent_dir: Path) -> Path:  # tempfile.TemporaryDirectory:
     return temp_dir
 
 
+def create_temp_dir(parent_dir: Path) -> Path:
+    """ Create a temp directory, which will be deleted on object destruction. """
+
+    temp_dir = tempfile.TemporaryDirectory(
+        prefix=f"{datetime.datetime.now().strftime('%Y-%m-%d_%H-%M-%S')}_",
+        dir=parent_dir,
+    )
+
+    return Path(temp_dir.name)
+
+
 def symlink(frm: Path, to: Path, force: bool = False):
     """ Create a symlink from one file to another. """
 
